==> ejc-ztpcdc-impl-3.0.0-20230505.055326-10-sources.jar: com/ejianc/business/dc/vo/DcFiledistributeMenuVO.java <==
package com.ejianc.business.dc.vo;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;

/**
 * 文件中心目录菜单
 *
 * @author generator
 */
public class DcFiledistributeMenuVO extends BaseVO {
    private static final long serialVersionUID = 1L;

    private Long projectId; // 项目ID
    private String projectCode; // 项目编码
    private String projectName; // 项目名称
    private String code; // 编号
    private String name; // 名称
    private Long attribute; // 文件属性
    private Integer orderNum; // 顺序号
    private Long menuType; // 菜单类型
    private String menuTypeCode; // 菜单类型编号
    private String wkflCode; // 工作流编号
    private String wkflName; // 工作流名称
    private String onlineId; // 在线编辑模板id
    private String onlineName; // 在线编辑模板名称
    private String onlineAttachment; // 在线编辑模板附件
    private Long createDeptId; // 创建部门id
    private Long orgId; // 所属项目组织id（公用类型为2时适用）
    private String orgCode; // 组织编码
    private String orgName; // 组织名称
    private Long parentOrgId; // 所属组织
    private String parentOrgCode; // 所属组织编码
    private String parentOrgName; // 所属组织名称

    public Long getProjectId() {
        return projectId;
    }

    @ReferDeserialTransfer
    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }

    public String getProjectCode() {
        return projectCode;
    }

    public void setProjectCode(String projectCode) {
        this.projectCode = projectCode;
    }

    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }

    public String getCode() {
        return code;
    }

    public void setCode(String code) {
        this.code = code;
    }

    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }

    public Long getAttribute() {
        return attribute;
    }

    public void setAttribute(Long attribute) {
        this.attribute = attribute;
    }

    public Integer getOrderNum() {
        return orderNum;
    }

    public void setOrderNum(Integer orderNum) {
        this.orderNum = orderNum;
    }

    public Long getMenuType() {
        return menuType;
    }

    public void setMenuType(Long menuType) {
        this.menuType = menuType;
    }

    public String getMenuTypeCode() {
        return menuTypeCode;
    }

    public void setMenuTypeCode(String menuTypeCode) {
        this.menuTypeCode = menuTypeCode;
    }

    public String getWkflCode() {
        return wkflCode;
    }

    public void setWkflCode(String wkflCode) {
        this.wkflCode = wkflCode;
    }

    public String getWkflName() {
        return wkflName;
    }

    public void setWkflName(String wkflName) {
        this.wkflName = wkflName;
    }

    public String getOnlineId() {
        return onlineId;
    }

    public void setOnlineId(String onlineId) {
        this.onlineId = onlineId;
    }

    public String getOnlineName() {
        return onlineName;
    }

    public void setOnlineName(String onlineName) {
        this.onlineName = onlineName;
    }

    public String getOnlineAttachment() {
        return onlineAttachment;
    }

    public void setOnlineAttachment(String onlineAttachment) {
        this.onlineAttachment = onlineAttachment;
    }

    @ReferSerialTransfer(referCode = "idm-employee")
    public Long getCreateDeptId() {
        return createDeptId;
    }

    @ReferDeserialTransfer
    public void setCreateDeptId(Long createDeptId) {
        this.createDeptId = createDeptId;
    }

    @ReferSerialTransfer(referCode="idm-org")
    public Long getOrgId() {
        return orgId;
    }

    @ReferDeserialTransfer
    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }

    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }

    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }

    @ReferSerialTransfer(referCode="idm-org")
    public Long getParentOrgId() {
        return parentOrgId;
    }

    @ReferDeserialTransfer
    public void setParentOrgId(Long parentOrgId) {
        this.parentOrgId = parentOrgId;
    }

    public String getParentOrgCode() {
        return parentOrgCode;
    }

    public void setParentOrgCode(String parentOrgCode) {
        this.parentOrgCode = parentOrgCode;
    }

    public String getParentOrgName() {
        return parentOrgName;
    }

    public void setParentOrgName(String parentOrgName) {
        this.parentOrgName = parentOrgName;
    }

}

==> ejc-ztpcdc-impl-3.0.0-20230811.071921-173-sources.jar: com/ejianc/business/dc/vo/DcFiledistributeMenuVO.java <==
package com.ejianc.business.dc.vo;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;

/**
 * 文件中心目录菜单
 *
 * @author generator
 */
public class DcFiledistributeMenuVO extends BaseVO {
    private static final long serialVersionUID = 1L;

    private Long projectId; // 项目ID
    private String projectCode; // 项目编码
    private String projectName; // 项目名称
    private String code; // 编号
    private String name; // 名称
    private Long attribute; // 文件属性
    private Integer orderNum; // 顺序号
    private Long menuType; // 菜单类型
    private String menuTypeCode; // 菜单类型编号
    private Long filecodeRuleId; // 外部编码取号规则id
    private String filecodeRuleName; // 外部编码取号规则名称
    private Long internalcodeRuleId; // 内部编码取号规则id
    private String internalcodeRuleName; // 内部编码取号规则名称
    private Long wkflCode; // 工作流编号
    private String wkflName; // 工作流名称
    private Long onlineId; // 在线编辑模板id
    private String onlineName; // 在线编辑模板名称
    private String onlineAttachment; // 在线编辑模板附件
    private Long createDeptId; // 创建部门id
    private Long orgId; // 所属项目组织id（公用类型为2时适用）
    private String orgCode; // 组织编码
    private String orgName; // 组织名称
    private Long parentOrgId; // 所属组织
    private String parentOrgCode; // 所属组织编码
    private String parentOrgName; // 所属组织名称

    @ReferSerialTransfer(referCode = "project-set")
    public Long getProjectId() {
        return projectId;
    }

    @ReferDeserialTransfer
    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }

    public String getProjectCode() {
        return projectCode;
    }

    public void setProjectCode(String projectCode) {
        this.projectCode = projectCode;
    }

    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }

    public String getCode() {
        return code;
    }

    public void setCode(String code) {
        this.code = code;
    }

    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }

    @ReferSerialTransfer(referCode = "support-defdoc")
    public Long getAttribute() {
        return attribute;
    }

    @ReferDeserialTransfer
    public void setAttribute(Long attribute) {
        this.attribute = attribute;
    }

    public Integer getOrderNum() {
        return orderNum;
    }

    public void setOrderNum(Integer orderNum) {
        this.orderNum = orderNum;
    }

    @ReferSerialTransfer(referCode = "support-defdoc")
    public Long getMenuType() {
        return menuType;
    }

    @ReferDeserialTransfer
    public void setMenuType(Long menuType) {
        this.menuType = menuType;
    }

    public String getMenuTypeCode() {
        return menuTypeCode;
    }

    public void setMenuTypeCode(String menuTypeCode) {
        this.menuTypeCode = menuTypeCode;
    }

    public Long getFilecodeRuleId() {
        return filecodeRuleId;
    }

    public void setFilecodeRuleId(Long filecodeRuleId) {
        this.filecodeRuleId = filecodeRuleId;
    }

    public String getFilecodeRuleName() {
        return filecodeRuleName;
    }

    public void setFilecodeRuleName(String filecodeRuleName) {
        this.filecodeRuleName = filecodeRuleName;
    }

    public Long getInternalcodeRuleId() {
        return internalcodeRuleId;
    }

    public void setInternalcodeRuleId(Long internalcodeRuleId) {
        this.internalcodeRuleId = internalcodeRuleId;
    }

    public String getInternalcodeRuleName() {
        return internalcodeRuleName;
    }

    public void setInternalcodeRuleName(String internalcodeRuleName) {
        this.internalcodeRuleName = internalcodeRuleName;
    }

    public Long getWkflCode() {
        return wkflCode;
    }

    public void setWkflCode(Long wkflCode) {
        this.wkflCode = wkflCode;
    }

    public String getWkflName() {
        return wkflName;
    }

    public void setWkflName(String wkflName) {
        this.wkflName = wkflName;
    }

    public Long getOnlineId() {
        return onlineId;
    }

    public void setOnlineId(Long onlineId) {
        this.onlineId = onlineId;
    }

    public String getOnlineName() {
        return onlineName;
    }

    public void setOnlineName(String onlineName) {
        this.onlineName = onlineName;
    }

    public String getOnlineAttachment() {
        return onlineAttachment;
    }

    public void setOnlineAttachment(String onlineAttachment) {
        this.onlineAttachment = onlineAttachment;
    }

    @ReferSerialTransfer(referCode = "idm-dept")
    public Long getCreateDeptId() {
        return createDeptId;
    }

    @ReferDeserialTransfer
    public void setCreateDeptId(Long createDeptId) {
        this.createDeptId = createDeptId;
    }

    @ReferSerialTransfer(referCode="idm-org")
    public Long getOrgId() {
        return orgId;
    }

    @ReferDeserialTransfer
    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }

    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }

    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }

    @ReferSerialTransfer(referCode="idm-org")
    public Long getParentOrgId() {
        return parentOrgId;
    }

    @ReferDeserialTransfer
    public void setParentOrgId(Long parentOrgId) {
        this.parentOrgId = parentOrgId;
    }

    public String getParentOrgCode() {
        return parentOrgCode;
    }

    public void setParentOrgCode(String parentOrgCode) {
        this.parentOrgCode = parentOrgCode;
    }

    public String getParentOrgName() {
        return parentOrgName;
    }

    public void setParentOrgName(String parentOrgName) {
        this.parentOrgName = parentOrgName;
    }

}
